# Julia SFTP Client 
Package for working with SFTP in Julia. Built on Downloads.jl, but in my opinion much easier to use. Downloads.jl is in turn based on Curl. 

The SFTP client supports username/password as well as certificates for authentication. 

The following methods are supported: readdir, download, upload, cd, rm, rmdir, mkdir, mv

___Note: You must first use your local sftp client to set up certificates___
This is done in Windows by using Command Line (cmd.exe) or Windows PowerShell. On Linux, use your favorite shell. 
Execute "sftp -o HostKeyAlgorithms=ecdsa-sha2-nistp256 myuser@siteIwantToConnectTo.com" and acccept any certificates. After this you should be able to connect via the Julia SFTP Client. 


___Note: Only do this if you have issues___
If it does not work, check your known_hosts file in your .ssh directory. ED25519 keys do not seem to work.

Use the ssh-keyscan tool: From command line, execute: ssh-keyscan -H [hostname],[ip_address]. Add the ecdsa-sha2-nistp256 line to your known_hosts file. This file is located in your .ssh-directory. This is directory is located in C:\Users\\{your_user}\\.ssh on Windows and ~/.ssh on Linux.

[API Documentation](https://stensmo.github.io/SFTPClient.jl/dev/)

___Note: Setting up certificate authentication___

To set up certificate authentication, create the certificates in the ~/.ssh/id_rsa and ~/.ssh/id_rsa.pub files. On Windows these are located in C:\Users\\{your user}\\.ssh. 

Then use the function  sftp = SFTP("sftp://mysitewhereIhaveACertificate.com", "myuser") to create an SFTP object.

More instructions for setting up the files id_rsa, and id_rsa.pub will follow


Examples:
```

    using SFTPClient
    sftp = SFTP("sftp://test.rebex.net/pub/example/", "demo", "password")
    files=readdir(sftp)
    # On Windows, replace this with an appropriate path
    downloadDir="/tmp/"
    SFTPClient.download.(sftp, files, downloadDir=downloadDir)

```
   
    You can also use it like this:
    
```
    
    df=DataFrame(CSV.File(SFTPClient.download(sftp, "/mydir/test.csv")))

```
